Bcselector — bcselector 0.0.38 documentation

# Bcselector

Python cost-sensitive feature selection library.

Contents

- Bcselector
  - What is it?
  - Installation
  - Quickstart
  - Bibliography
  - Citations
- Examples
  - Data Generation
  - Feature Selection
- API Reference
  - Feature Selectors
  - Data Generation
  - Datasets
  - Information Theory
  - Filter Methods
- History
  - 0.0.36
  - 0.0.35
  - 0.0.32
  - 0.0.31
  - 0.0.30
  - 0.0.24
  - 0.0.23
  - 0.0.22
  - 0.0.21

## Indices and tables

- Index

- Module Index

- Search Page